#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_FAST_FREXP_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_FAST_FREXP_HPP_INCLUDED

#include <nt2/ieee/include/functions/scalar/fast_frexp.hpp>

#endif
